OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Նիշքը վերբերռնված է",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Վերբեռնած նիշքը գերազանցում է upload_max_filesize սահմանված php.ini֊ում",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Վերբեռնած նիշքը գերազանցում է MAX_FILE_SIZE, որը սահմանված է HTML ձևաթղթում",
    "The file was only partially uploaded" : "Նիշքի մի մասն է վերբեռնված",
    "No file was uploaded" : "Ոչ մի նիշք չի վերնբեռնվել",
    "Missing a temporary folder" : "Բացակայում է ժամանակավոր պանակը",
    "Could not write file to disk" : "Չհաջողվեց գրառել նիշքը սկավառակի վրա",
    "A PHP extension stopped the file upload" : "PHP֊ի ընդլայնումն կանգնեցրեց նիշքի վերբեռնումը",
    "File not found" : "Նիշքը չգտնվեց",
    "Translate" : "Թարգմանել",
    "Copy link" : "Պատճենել հղումը",
    "guest" : "հյուր",
    "Saved" : "Պահված",
    "Link" : "Հղում",
    "Cancel" : "չեղարկել",
    "URL" : "URL",
    "Upload" : "Բեռնել",
    "Edit" : "մշակել",
    "Source code" : "ծրագրի կոդը",
    "Details" : "Մանրամասներ",
    "Choose" : "Ընտրել"
},
"nplurals=2; plural=(n != 1);");
